@@ -1,8 +1,11 @@
 from ._cemba import *
 from ._aibs import *
 from ._broad import *
+from ._cemba_epi_retro import *
 from ._brain_region import *
 from ._ref import *
+from ._integration import *
+from .palette import PALETTES
 import pathlib
 
 
